<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Kontrolli i fundit më: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Nëse e braktisni programin beta, s’do të merrni më përditësime beta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dilni</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Shihni Regjistra Përditësimesh</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Historik Përditësimesh</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Pa historik përditësimesh</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Përditësime Sistemi</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Përditësime Sigurie</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Sjell një përditësim përmbledhës që përfshin veçori të reja, përditësime cilësie dhe përditësime sigurie</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Sjell përditësime sigurie</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Datë instalimi:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Shihni Hollësitë</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Kohë hedhjeje në qarkullim:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Palose</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Regjistër Përditësimesh</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Eksportoje në desktop</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>ASNJË</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>I ULËT</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MESATAR</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>I LARTË</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>KRITIK</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>rrezik kritik</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>rrezik i lartë</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>rrezik mesatar</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>rrezik i ulët</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>i panjohur</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Ky përditësim ndreq</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>cenueshmëri</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>cenueshmëri</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 nga %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>për më tepër hollësi, ju lutemi, vizitoni </translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Po kontrollohet për përditësime, ju lutemi, pritni…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Sistemi juaj është i përditësuar</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Gabim i panjohur</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Shkarkimi i përditësimeve dështoi. Ju lutemi, së pari, lironi %1 hapësirë në disk.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Gabim varësish, s’u arrit të pikasen përditësimet</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Ju lutemi, kontrolloni lidhjen tuaj me rrjetin dhe riprovoni.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Shkarkimi i përditësimeve dështoi. Ju lutemi, kontrolloni rrjetin dhe riprovoni.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>S’arrihet të kryhet kopjeruajtje sistemi. Nëse vazhdoni përditësimet, s’mund të ktheheni prapa te sistemi i vjetër më vonë.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Nëse vazhdoni përditësimet, s’mund të ktheheni prapa te sistemi i vjetër më vonë.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Hapësirë disku e pamjaftueshme</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Gabim DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Mungon kartelë</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>Lidhja me shërbimin s’është normale, ju lutemi, kontrolloni rrjetin dhe riprovoni</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>Formësimi i depos së burimeve s’është i vlefshëm, ju lutemi, kontrolloni dhe riprovoni.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Rikontrollo</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Rregulla Privatësie</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Që të përdorni këtë software, duhet të pranoni %1 që shoqëron përditësimet e software-it.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Për të pasur punim më të mirë, hapni çelësat që gjenden nën Lëndë Përditësimi</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Sistemi juaj s’është aktivizuar dhe s’u arrit të lidhej me shërbime përditësimesh</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Përditësimet e sistemit janë të çaktivizuara. Ju lutemi, për ndihmë, lidhuni me përgjegjësin tuaj</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>Sistemi ka të aktivizuar funksion rikthimi dhe s’mbulon përditësime. Nëse keni ndonjë pyetje, ju lutemi, lidhuni me përgjegjësin.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>Përditësimet janë shkarkuar tashmë. Ç’doni të bëhet?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Instalim Heshtazi</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Përditësoje dhe Rinisu</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Përditësoje dhe Fiku</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Ndërrim i Mençur Pasqyrash</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Lloj Përditësimi</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Përditësime Funksionesh</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Sjell një përditësim përmbledhës që përfshin veçori të reja, përditësime cilësie dhe përditësime sigurie</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Përditësime Sigurie</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Sjell përditësime sigurie</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Përditësime Palësh të Treta</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Sjell përditësime për burime shtesë deposh</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Kufizo Shpejtësinë</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Rregullim Kufiri</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Vetëshkarkoje</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Aktivizimi i “Vetëshkarko Përditësime” di të shkarkojë automatikisht përditësime, kur bëhet lidhja në internet</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Shkarko kur është i Plogësht</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Fillo më</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Përfundoje më</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Rregullime të Mëtejshme</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Njoftim Përditësimesh</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Spastro Fshehtinë Paketash</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historik Përditësimesh</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Shiheni</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Bëhuni Pjesë e Kanalit të Testimeve të Brendshme</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Klikoni këtu që të plotësoni aplikimin</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Zgjeroje</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Palose</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Lejohen vetëm numra mes 1-99999</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Përditësime Sistemi</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>U ndreqën disa të meta të ditura dhe cenueshmëri sigurie</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Përditësime Sigurie</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Depo Palësh të Treta</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>Eksportimi i regjistrit dështoi, ju lutemi, riprovoni</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Regjistri u eksportua te desktopi</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Përditësim</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Ju lutemi, vëreni në prizë dhe mandej instaloni përditësimet.</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Përditësim Sistemi</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Përditësim dhe përmirësim sistemi</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Rregullime Përditësimesh</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Instalim</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Shkarkimi i përditësimit u plotësua</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Instalo përditësimet</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Madhësi përditësimi: </translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Shkarkimi i përditësimit dështoi</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Po shkarkohen përditësime…</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Shkarkim</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Formësoni rregullime Përditësimi、Përditësime Sigurie、Vetëshkarkim Përditësimedhe dhe Njoftim Përditësimesh</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Riniseni tani</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Shkarkoje</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Po instalohen përditësimet…</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Riprovoni</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Vazhdo Përditësimin</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Ka Përditësime</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Instalimi i përditësimeve dështoi</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Që të garantohet funksionimi i saktë i sistemit dhe aplikacioneve tuaja, ju lutemi, pas përditësimit, rinisni kopmjuterin tuaj</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Kopjeruajtje në kryerje e sipër…</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Kopjeruajtje në kryerje e sipër</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Kopjeruajtja dështoi</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Instalim i suksesshëm i përditësimeve</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Nëse vazhdoni përditësimet, s’mund të ktheheni mbrapsht më vonë te sistemi i mëparshëm.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Riprovoni</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Vazhdo ta Përditësosh</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>Kapaciteti i baterisë është më pak se 60%. Që të merren me sukses përditësime, ju lutemi, vëreni në prizë.</translation>
    </message>
</context>
</TS>